package org.enableit.tools.email.client;

// Java imports
import java.io.InputStream ;
import java.net.URL ;
import java.util.Properties ;
import javax.naming.InitialContext ;
import javax.rmi.PortableRemoteObject ; 

// JUnit imports
import junit.framework.* ;

// Log4J imports
import org.apache.log4j.Logger;

import org.enableit.tools.email.interfaces.Attachment ; 
import org.enableit.tools.email.interfaces.Email ; 
import org.enableit.tools.email.interfaces.EmailConfigBean ; 
import org.enableit.tools.email.interfaces.EmailHome ; 

import org.enableit.tools.email.test.Constants ; 

/**
 * Tests EmailEJB class.
 */
public class EmailEJBTestClient2 extends junit.framework.TestCase {
/*
 * Properties
 */

    /**
     * Define a static Logger variable for logging
     */
    private static Logger logger = Logger.getLogger(EmailEJBTestClient2.class);

    private static Properties ejbContextProps ; 
    
/*
 * Constructors
 */
	/**
	 * Default Constructor
	 */
	public EmailEJBTestClient2(String name) {
        super(name) ;
	}

/*
 * Methods
 */

    /**
     * Defines all the tests for the Web Service application including
     * tests in this class.
     */
    public static Test suite() {
        TestSuite suite= new TestSuite(EmailEJBTestClient2.class);
        return suite;
    }

    /**
     * Define the test environment, notably the JNDI context.
     */
    public void setUp()
    throws java.lang.Exception {

        InputStream is = this.getClass().getResourceAsStream("ejbContext.properties") ; 
        if (is == null) {
            System.out.println("EJB Context properties not available.") ;   
            return ; 
        } else {  
            ejbContextProps = new Properties() ; 
            ejbContextProps.load(is) ; 
            is.close() ; 
            is = null ;
        } 
    }

    public void tearDown() 
        throws Exception { 
        
    } 

    public void testEmailEJBBasic() 
        throws Exception { 

        assertNotNull("EJB Context properties not available.", ejbContextProps) ;   
        
        assertNotNull("Did not specify the JNDI name for the Email EJB", Constants.EMAIL_HOME) ; 
        InitialContext ejbContext = new InitialContext(ejbContextProps) ; 
        assertNotNull("Unable to create JNDI context from specified properties", ejbContext) ; 

        Object obj = ejbContext.lookup(Constants.EMAIL_HOME) ; 
        logger.debug("EJB server returned object type: " + obj.getClass().getName()) ; 
        assertNotNull("Null home returned from EJB lookup", obj) ; 
        EmailHome home = (EmailHome) PortableRemoteObject.narrow(obj, EmailHome.class) ; 
        //EmailHome home = (EmailHome) obj ; 

        Email email = home.create() ; 
        assertNotNull("Null remote returned from EJB home", email) ; 

        email.sendEmail(Constants.TO, Constants.FROM, 
                Constants.SUBJECT, Constants.MESSAGE) ; 

        email.remove() ; 
        email = null ;
    } 

    public void testEmailEJBAttachment() 
        throws Exception { 
        
        assertNotNull("EJB Context properties not available.", ejbContextProps) ;   

        assertNotNull("Did not specify the JNDI name for the Email ejb", Constants.EMAIL_HOME) ; 
        InitialContext ejbContext = new InitialContext(ejbContextProps) ; 
        assertNotNull("Unable to create JNDI context from specified properties", ejbContext) ; 

        Object obj = ejbContext.lookup(Constants.EMAIL_HOME) ; 
        assertNotNull("Null home returned from EJB lookup", obj) ; 
        EmailHome home = (EmailHome)PortableRemoteObject.narrow(obj, EmailHome.class) ; 

        Email email = home.create() ; 
        assertNotNull("Null remote returned from EJB home", email) ; 

        email.sendEmail(Constants.TO, Constants.FROM, 
                Constants.SUBJECT, Constants.MESSAGE, Constants.ATTACHMENT_TEXT ) ; 

        email.remove() ; 
        email = null ;
    } 

    public void testEmailEJBAttachmentUrl() 
        throws Exception { 
        
        assertNotNull("EJB Context properties not available.", ejbContextProps) ;   
        
        assertNotNull("Did not specify the JNDI name for the Email ejb", Constants.EMAIL_HOME) ; 
        InitialContext ejbContext = new InitialContext(ejbContextProps) ; 
        assertNotNull("Unable to create JNDI context from specified properties", ejbContext) ; 

        Object obj = ejbContext.lookup(Constants.EMAIL_HOME) ; 
        assertNotNull("Null home returned from EJB lookup", obj) ; 
        EmailHome home = (EmailHome)PortableRemoteObject.narrow(obj, EmailHome.class) ; 

        Email email = home.create() ; 
        assertNotNull("Null remote returned from EJB home", email) ; 

        email.sendEmail(Constants.TO, Constants.FROM, Constants.SUBJECT, 
                Constants.MESSAGE, new URL(Constants.ATTACHMENT_URL) ) ; 

        email.remove() ; 
        email = null ;
    } 

    public void testEmailEJBSecureAttachmentUrl() 
        throws Exception { 
        
        assertNotNull("EJB Context properties not available.", ejbContextProps) ;   
        
        assertNotNull("Did not specify the JNDI name for the Email ejb", Constants.EMAIL_HOME) ; 
        InitialContext ejbContext = new InitialContext(ejbContextProps) ; 
        assertNotNull("Unable to create JNDI context from specified properties", ejbContext) ; 

        Object obj = ejbContext.lookup(Constants.EMAIL_HOME) ; 
        assertNotNull("Null home returned from EJB lookup", obj) ; 
        EmailHome home = (EmailHome)PortableRemoteObject.narrow(obj, EmailHome.class) ; 

        Email email = home.create() ; 
        assertNotNull("Null remote returned from EJB home", email) ; 

        email.sendEmail(Constants.TO, Constants.FROM, Constants.SUBJECT, 
                Constants.MESSAGE, new URL(Constants.SECURE_ATTACHMENT_URL)) ; 

        email.remove() ; 
        email = null ;
    } 
       
}
