package org.enableit.tools.email.client;

// Java imports
import java.io.File ;
import java.io.InputStream ;
import java.net.URL ;
import java.util.Properties ;
import javax.naming.InitialContext ;
import javax.activation.DataHandler ; 
import javax.activation.FileDataSource ; 
import javax.rmi.PortableRemoteObject ; 

// JUnit imports
import junit.framework.* ;

// Log4J imports
import org.apache.log4j.Logger;

// email classes 
import org.enableit.tools.email.interfaces.Attachment ; 
import org.enableit.tools.email.interfaces.Email ; 
import org.enableit.tools.email.interfaces.EmailConfigBean ; 
import org.enableit.tools.email.interfaces.EmailHome ; 

import org.enableit.tools.email.test.Constants ; 

/**
 * Tests EmailEJB class.
 */
public class EmailEJBTestClientExcelAttachment 
        extends TestCase {
/*
 * Properties
 */

    /**
     * Define a static Logger variable for logging
     */
    private static Logger logger = Logger.getLogger(EmailEJBTestClientExcelAttachment.class);

    private static Properties ejbContextProps ; 
    
/*
 * Constructors
 */
	/**
	 * Default Constructor
	 */
	public EmailEJBTestClientExcelAttachment(String name) {
        super(name) ;
	}

/*
 * Methods
 */

    /**
     * Defines all the tests for the Web Service application including
     * tests in this class.
     */
    public static Test suite() {
        TestSuite suite= new TestSuite(EmailEJBTestClientExcelAttachment.class);
        return suite;
    }

    /**
     * Define the test environment, notably the JNDI context.
     */
    public void setUp()
    throws java.lang.Exception {

        InputStream is = this.getClass().getResourceAsStream("ejbContext.properties") ; 
        if (is == null) {
            System.out.println("EJB Context properties not available.") ;   
            return ; 
        } else {  
            ejbContextProps = new Properties() ; 
            ejbContextProps.load(is) ; 
            is.close() ; 
            is = null ;
        } 
    }

    public void tearDown() 
        throws Exception { 
        
    } 

    /**  
     * Tests attaching a local Excel file and sending it.
     */
    public void testEmailEJBExcelFileAttachment() 
        throws Exception { 
        
        assertNotNull("EJB Context properties not available.", ejbContextProps) ;   

        assertNotNull("Did not specify the JNDI name for the Email ejb", Constants.EMAIL_HOME) ; 
        InitialContext ejbContext = new InitialContext(ejbContextProps) ; 
        assertNotNull("Unable to create JNDI context from specified properties", ejbContext) ; 

        Object obj = ejbContext.lookup(Constants.EMAIL_HOME) ; 
        assertNotNull("Null home returned from EJB lookup", obj) ; 
        EmailHome home = (EmailHome)PortableRemoteObject.narrow(obj, EmailHome.class) ; 

        Email email = home.create() ; 
        assertNotNull("Null remote returned from EJB home", email) ; 

        EmailConfigBean bean = 
                new EmailConfigBean(Constants.TO, Constants.FROM, 
                Constants.SUBJECT, Constants.MESSAGE) ;
        String excelFileName = ((URL) this.getClass().getResource("test.xls")).getFile() ; 
        File excelFile = new File(excelFileName) ; 
        /*FileDataSource ds = new FileDataSource(excelFile); 
        DataHandler dh = new DataHandler(ds) ; 
        Attachment attachment = new Attachment(dh.getContent(), dh.getContentType()) ;
        */
        Attachment attachment = new Attachment(excelFile) ;
        bean.addAttachment(attachment) ; 
            
        email.sendEmail(bean) ; 
        	
        email.remove() ; 
        email = null ;
    } 

    /**  
     * Tests attaching a local Excel file and sending it.
     */
    public void testEmailEJBExcelURLAttachment() 
        throws Exception { 
        
        assertNotNull("EJB Context properties not available.", ejbContextProps) ;   

        assertNotNull("Did not specify the JNDI name for the Email ejb", Constants.EMAIL_HOME) ; 
        InitialContext ejbContext = new InitialContext(ejbContextProps) ; 
        assertNotNull("Unable to create JNDI context from specified properties", ejbContext) ; 

        Object obj = ejbContext.lookup(Constants.EMAIL_HOME) ; 
        assertNotNull("Null home returned from EJB lookup", obj) ; 
        EmailHome home = (EmailHome)PortableRemoteObject.narrow(obj, EmailHome.class) ; 

        Email email = home.create() ; 
        assertNotNull("Null remote returned from EJB home", email) ; 

        EmailConfigBean bean = 
                new EmailConfigBean(Constants.TO, Constants.FROM, 
                Constants.SUBJECT, Constants.MESSAGE) ;
        //String excelFileName = ((URL) this.getClass().getResource("test.xls")).getFile() ; 
        URL excelFile = new URL(Constants.EXCEL_ATTACHMENT_URL) ; 
        /*URLDataSource ds = new URLDataSource(excelFile); 
        DataHandler dh = new DataHandler(ds) ; 
        Attachment attachment = new Attachment(dh.getContent(), dh.getContentType()) ;
        */
        Attachment attachment = new Attachment(excelFile) ;
        bean.addAttachment(attachment) ; 
            
        email.sendEmail(bean) ; 
        	
        email.remove() ; 
        email = null ;
    } 
       
}
 