/* 
 *     PROJECT          : emailEJB 
 *
 *     COPYRIGHT        : Copyright (C) 1999-2003 Tim Stephenson
 *
 *     contact me at gpl@enableit.org.
 * 
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 * 
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */ 
package org.enableit.tools.email.interfaces; 
 
// Java imports
import java.io.File ; 
import java.io.Serializable ; 
import java.net.URL ; 

/**  
 * A <code>JavaBean</code> encapsulating the data for an email attachment.
 * @author Tim Stephenson
 */
public class Attachment extends Object implements Serializable {

/*
 * Properties
 */

    /**  
     * The object to form the attachment.
     */
    private Object attachment ; 

    /**  
     * The mime type of this attachment.
     */
    private String mimeType ; 

    /**  
     * The name to give this attachment.
     */
    private String name ; 

/*
 * Constructors
 */
    /** 
     * Constructor for a <code>File</code> attachment.
     * @param attachment File to attach. 
     *      Mime type and name will be derived from the File.
     */
    public Attachment(File attachment) {
        setAttachment(attachment) ; 
        setName(attachment.getName()) ; 
    }

    /** 
     * Constructor for a <code>URL</code> attachment.
     * @param attachment URL to attach. 
     *      Mime type and name will be derived from the URL.
     */
    public Attachment(URL attachment) {
        setAttachment(attachment) ; 
        setName(attachment.getFile().substring(1)) ; 
    }

    /** 
     * Constructor setting all the properties in one go.
     * @param attachment Object to attach. 
     * @param mimeType The mime type of the object. Note that the Mime 
     *          type must be recognised by the Java activation framework.
     * @param name Name to give to the attachment.
     */
    public Attachment(Object attachment, String mimeType, String name) {
        setAttachment(attachment) ; 
        setMimeType(mimeType) ; 
        setName(name) ; 
    }

/*
 * Methods
 */

    /** 
     * @return The attachment object.
     */
    public Object getAttachment() {
        return this.attachment ;
    }
    
    /**
     * @param attachment New attachment object.
     */
    public void setAttachment(Object attachment) { 
        this.attachment = attachment ;
    } 

    /** 
     * @return The mime type of the attachment. 
     */
    public String getMimeType() {
        return this.mimeType ;
    }
    
    /**
     * @param mimeType The mime Type of this attachment. 
     */
    public void setMimeType(String mimeType) { 
        this.mimeType = mimeType ;
    } 

    /** 
     * @return The name to give the attachment. 
     */
    public String getName() {
        return this.name ;
    }
    
    /**
     * @param name The name to give the attachment. 
     */
    public void setName(String name) { 
        this.name = name ;
    } 

    /**  
     * CVS info about this class and its current version
     */
    public static final String ABOUT = "$Id: Attachment.java,v 1.1 2003/01/27 07:36:17 TimAndVicky Exp $" ;

}
