/* 
 *     PROJECT          : emailEJB 
 *
 *     COPYRIGHT        : Copyright (C) 1999-2003 Tim Stephenson
 *
 *     contact me at gpl@enableit.org.
 * 
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 * 
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 * 
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */ 
package org.enableit.tools.email.interfaces;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/**  
 * A <code>JavaBean</code> encapsulating the configuration of an email to be 
 * sent.
 * @author Tim Stephenson
 */
public class EmailConfigBean extends Object implements Serializable {

    /** 
     * A <code>String</code> of the email addresses to send to, 
     *      comma-separated. 
     */
    private String to;

    /** The subject line of the email. */
    private String subject;
    
    /** Text to place in the body of the email. */
    private String message;
    
    /** The address the email will appear to be from. */
    private String from;
    
    /** <code>List</code> of <code>Attachments</code>. */
    private List attachmentList;
   
    /**  
     * Default constructor.
     */
    public EmailConfigBean() { 
        attachmentList = new ArrayList() ; 
    } 

    /**  
     * Constructor setting the basics (but not attachments) in one go.
     * @param to Target email address(es). If more than one use comma to 
     *      separate.
     * @param from Message 'from' address. If supplied this overrides the
     *      default in the JNDI context.
     * @param subject Subject for the mail message.
     * @param message Body text for the mail message.
     */
    public EmailConfigBean(String to, String from, 
            String subject, String message) {
        this() ; 
        setTo(to) ; 
        setFrom(from) ; 
        setSubject(subject) ; 
        setMessage(message) ; 
    } 

    /** 
     * @return <code>String</code> of the 'to' email addresses, comma-separated
     */
    public String getTo() {
        return to;
    }
   
    /** @param newTo <code>String</code> of the 'to' email addresses */
    public void setTo(String newTo) {
        to = newTo;
    }
   
    /**  
     * Adds a new addressee.
     * @param toAddress Extra email address to add.
     */
    public void addTo(String toAddress) { 
        to += (", " + toAddress) ; 
    } 
    
    /** @return Subject for the email */
    public String getSubject() {
        return subject;
    }
   
    /** @param newSubject Subject for the email */
    public void setSubject(String newSubject) {
        subject = newSubject;
    }
   
    /** @return Text for the message body */
    public String getMessage() {
        return message;
    }
   
    /** @param newMessage Text for the message body */
    public void setMessage(String newMessage) {
        message = newMessage;
    }
   
    /** @return The From address for the email. */
    public String getFrom() {
        return from;
    }
   
    /** @param newFrom The From address for the email. */
    public void setFrom(String newFrom) {
        from = newFrom;
    }

    /** 
     * @return <code>List</code> of either <code>Objects</code> or 
     * <code>java.net.URLs</code> to send to the 'to' email addresses 
     * as attachments. 
     */
    public List getAttachmentList() {
        return attachmentList;
    }

    /**  
     * Adds a new attachment.
     * @param attachment The <code>Attachment</code> to add to the 
     *      list for sending.
     */
    public void addAttachment(Attachment attachment) { 
        attachmentList.add(attachment) ; 
    } 

}