package org.enableit.tools.email.ejb;

// Java imports
import java.io.File ;
import java.io.InputStream ;
import java.net.URL ;
import java.util.Properties ;
import javax.naming.InitialContext ;
import javax.activation.DataHandler ; 
import javax.activation.FileDataSource ; 
import javax.rmi.PortableRemoteObject ; 

// JUnit imports
import junit.framework.* ;

// Log4J imports
import org.apache.log4j.Logger;

// email classes 
import org.enableit.tools.email.interfaces.Attachment ; 
import org.enableit.tools.email.interfaces.Email ; 
import org.enableit.tools.email.interfaces.EmailConfigBean ; 
import org.enableit.tools.email.interfaces.EmailHome ; 

import org.enableit.tools.email.test.Constants ; 

/**
 * Tests EmailEJB class.
 */
public class EmailExcelAttachmentTest 
        extends TestCase {
/*
 * Properties
 */

    /**
     * Define a static Logger variable for logging
     */
    private static Logger logger = Logger.getLogger(EmailExcelAttachmentTest.class);

    /**  
     * Local reference to the EJB impl class for testing purposes.
     */
    private static EmailBean email ; 

/*
 * Constructors
 */
	/**
	 * Default Constructor
	 */
	public EmailExcelAttachmentTest(String name) {
        super(name) ;
	}

/*
 * Methods
 */

    /**
     * Defines all the tests for the Web Service application including
     * tests in this class.
     */
    public static Test suite() {
        TestSuite suite= new TestSuite(EmailExcelAttachmentTest.class);
        return suite;
    }

    /**
     * Define the test environment, notably the JNDI context.
     */
    public void setUp()
    throws java.lang.Exception {

        email = new EmailBean() ; 
        email.initialise(Constants.PROTOCOL, Constants.MBOX, Constants.SEND,
                Constants.HOST, Constants.USER, Constants.PASSWD, 
                Constants.MAILER, Constants.FROM, Constants.DEBUG, 
                Constants.BLANK_SUBJECT) ; 
    }

    public void tearDown() 
        throws Exception { 
        
    } 

    /**  
     * Tests attaching a local Excel file and sending it.
     */
    public void testEmailEJBExcelFileAttachment() 
        throws Exception { 
        
        assertNotNull("Null EJB impl class", email) ; 

        EmailConfigBean bean = 
                new EmailConfigBean(Constants.TO, Constants.FROM, 
                Constants.SUBJECT, Constants.MESSAGE) ;
        String excelFileName = ((URL) this.getClass().getResource("test.xls")).getFile() ; 
        File excelFile = new File(excelFileName) ; 
        /*FileDataSource ds = new FileDataSource(excelFile); 
        DataHandler dh = new DataHandler(ds) ; 
        Attachment attachment = new Attachment(dh.getContent(), dh.getContentType()) ;
        */
        Attachment attachment = new Attachment(excelFile, "application/excel") ;
        bean.addAttachment(attachment) ; 
            
        email.sendEmail(bean) ; 
        	
        email = null ;
    } 

    /**  
     * Tests attaching a local Excel file and sending it.
     */
    public void testEmailEJBExcelURLAttachment() 
        throws Exception { 
        
        assertNotNull("Null EJB impl class", email) ; 

        EmailConfigBean bean = 
                new EmailConfigBean(Constants.TO, Constants.FROM, 
                Constants.SUBJECT, Constants.MESSAGE) ;
        //String excelFileName = ((URL) this.getClass().getResource("test.xls")).getFile() ; 
        URL excelFile = new URL(Constants.EXCEL_ATTACHMENT_URL) ; 
        /*URLDataSource ds = new URLDataSource(excelFile); 
        DataHandler dh = new DataHandler(ds) ; 
        Attachment attachment = new Attachment(dh.getContent(), dh.getContentType()) ;
        */
        Attachment attachment = new Attachment(excelFile) ;
        bean.addAttachment(attachment) ; 
            
        email.sendEmail(bean) ; 
        	
        email = null ;
    } 
       
    
    public static void main (String[] args) { 
      junit.textui.TestRunner.run(EmailExcelAttachmentTest.class) ; 
    } 
}
